@@ -3,17 +3,16 @@ TFLite model base class
 """
 from typing import Any, List
 
-import numpy as np  # type: ignore
-
+import numpy as np
 
 try:
-    import tflite_runtime.interpreter as tflite  # type: ignore
+    import tflite_runtime.interpreter as tflite
 except ModuleNotFoundError:
-    import tensorflow.lite as tflite  # type: ignore
+    import tensorflow.lite as tflite
 
 
 class TFLiteModel:
-    """ TFLite model base class for managing multiple inputs/outputs
+    """TFLite model base class for managing multiple inputs/outputs
 
     Args:
         model_path (str): Path to .tflite model file
@@ -30,8 +29,8 @@ class TFLiteModel:
         self._output_details = self._interpreter.get_output_details()
         self._interpreter.allocate_tensors()
 
-    def __call__(self, *args) -> List[np.ndarray]:
-        """ Forward pass of the TFLite model
+    def __call__(self, *args: Any) -> List[np.ndarray]:
+        """Forward pass of the TFLite model
 
         Args:
             inputs (Any): inputs to the TFLite model
@@ -52,7 +51,7 @@ class TFLiteModel:
 
     @property
     def input_details(self) -> List[Any]:
-        """ Property for accesing the TFLite model input_details
+        """Property for accesing the TFLite model input_details
 
         Returns: Input details for the TFLite model
 
@@ -61,7 +60,7 @@ class TFLiteModel:
 
     @property
     def output_details(self) -> List[Any]:
-        """ Property for accesing the TFLite model output_details
+        """Property for accesing the TFLite model output_details
 
         Returns: Output details for the TFLite model
 
