@@ -2,17 +2,21 @@
 This module contains the class for detecting
 the presence of keywords in an audio stream
 """
+import logging
 import os
+from typing import Any
 
-import numpy as np  # type: ignore
+import numpy as np
 
 from spokestack.context import SpeechContext
 from spokestack.models.tensorflow import TFLiteModel
-from spokestack.wakeword.ring_buffer import RingBuffer
+from spokestack.ring_buffer import RingBuffer
+
+_LOG = logging.getLogger(__name__)
 
 
 class WakewordTrigger:
-    """ Detects the presence of a wakeword in the audio input
+    """Detects the presence of a wakeword in the audio input
 
     Args:
             pre_emphasis (float): The value of the pre-emmphasis filter
@@ -32,6 +36,7 @@ class WakewordTrigger:
         fft_hop_length: int = 10,
         model_dir: str = "",
         posterior_threshold: float = 0.5,
+        **kwargs: Any,
     ) -> None:
 
         self.pre_emphasis: float = pre_emphasis
@@ -88,8 +93,8 @@ class WakewordTrigger:
         self._prev_sample: float = 0.0
         self._is_speech: bool = False
 
-    def __call__(self, context: SpeechContext, frame) -> None:
-        """ Entry point of the trigger
+    def __call__(self, context: SpeechContext, frame: np.ndarray) -> None:
+        """Entry point of the trigger
 
         Args:
             context (SpeechContext): current state of the speech pipeline
@@ -109,9 +114,11 @@ class WakewordTrigger:
 
         # reset on vad fall deactivation
         if vad_fall:
+            if not context.is_active:
+                _LOG.info(f"wake: {self._posterior_max}")
             self.reset()
 
-    def _sample(self, context: SpeechContext, frame) -> None:
+    def _sample(self, context: SpeechContext, frame: np.ndarray) -> None:
         # convert the PCM-16 audio to float32 in (-1.0, 1.0)
         frame = frame.astype(np.float32) / (2 ** 15 - 1)
         frame = np.clip(frame, -1.0, 1.0)
@@ -144,7 +151,7 @@ class WakewordTrigger:
         # compute mel spectrogram
         self._filter(context, frame)
 
-    def _filter(self, context: SpeechContext, frame) -> None:
+    def _filter(self, context: SpeechContext, frame: np.ndarray) -> None:
         # add the batch dimension and compute the mel spectrogram with filter model
         frame = np.expand_dims(frame, 0)
         frame = self.filter_model(frame)[0]
@@ -176,10 +183,11 @@ class WakewordTrigger:
         frame = np.expand_dims(frame, 0)
         posterior = self.detect_model(frame)[0][0][0]
 
-        if posterior > self._posterior_threshold:
-            context.is_active = True
         if posterior > self._posterior_max:
             self._posterior_max = posterior
+        if posterior > self._posterior_threshold:
+            context.is_active = True
+            _LOG.info(f"wake: {self._posterior_max}")
 
     def reset(self) -> None:
         """ Resets the currect WakewordDetector state """
